Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/richdocuments.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'lib/db/op.php')
-rw-r--r--lib/db/op.php12
1 files changed, 6 insertions, 6 deletions
diff --git a/lib/db/op.php b/lib/db/op.php
index e795da6d..ee8cf760 100644
--- a/lib/db/op.php
+++ b/lib/db/op.php
@@ -1,6 +1,6 @@
<?php
/**
* ownCloud - Documents App
*
* @author Victor Dubiniuk
* @copyright 2013 Victor Dubiniuk victor.dubiniuk@gmail.com
@@ -9,15 +9,15 @@
* later.
*/
-namespace OCA\Documents\Db;
+namespace OCA\Richdocuments\Db;
-class Op extends \OCA\Documents\Db {
+class Op extends \OCA\Richdocuments\Db {
- const DB_TABLE = '`*PREFIX*documents_op`';
+ const DB_TABLE = '`*PREFIX*richdocuments_op`';
- protected $tableName = '`*PREFIX*documents_op`';
+ protected $tableName = '`*PREFIX*richdocuments_op`';
- protected $insertStatement = 'INSERT INTO `*PREFIX*documents_op` (`es_id`, `optype`, `member`, `opspec`) VALUES (?, ?, ?, ?)';
+ protected $insertStatement = 'INSERT INTO `*PREFIX*richdocuments_op` (`es_id`, `optype`, `member`, `opspec`) VALUES (?, ?, ?, ?)';
public static function addOpsArray($esId, $memberId, $ops){
$opObj = new Op();
@@ -1,6 +1,6 @@
<?php
/**
- * ownCloud - Documents App
+ * ownCloud - Richdocuments App
*
* @author Victor Dubiniuk